@@ -1,5 +1,5 @@
 var servicecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1LayerFilter =
 [
-    [ "XInitialization", "servicecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1LayerFilter.html#a62f2ca53a1a1cd25174b62b78ef7d524", null ],
+    [ "com::sun::star::lang::XInitialization", "servicecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1LayerFilter.html#a62f2ca53a1a1cd25174b62b78ef7d524", null ],
     [ "XLayer", "servicecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1LayerFilter.html#ad87fdf37df6052b2fb1314d441fed97a", null ]
 ];
\ No newline at end of file
